#!/bin/sh
# Reading config file
source /home/user/.config/ereswap/config

# Updating user's defined swaps and it's capabilities in rcS-late
sed -i "s@mmcblk.p.\([^$]\)@$swap0\1@g" /etc/event.d/rcS-late
sed -i "s/mmcblk.p.$/$swap2/" /etc/event.d/rcS-late

# Huge thanks to Sc0rpius for help with (basically, creating) this script!